Author: glebius
Date: Wed Mar  4 22:32:40 2020
New Revision: 358657
URL: https://svnweb.freebsd.org/changeset/base/358657

Log:
  Fix spelling of "dropped".
  
  Submitted by: Lutz Donnerhacke
  Differential Revision:        https://reviews.freebsd.org/D23954

Modified:
  head/share/man/man4/ng_car.4
  head/sys/netgraph/ng_car.c
  head/sys/netgraph/ng_car.h

Modified: head/share/man/man4/ng_car.4
==============================================================================
--- head/share/man/man4/ng_car.4        Wed Mar  4 22:31:41 2020        
(r358656)
+++ head/share/man/man4/ng_car.4        Wed Mar  4 22:32:40 2020        
(r358657)
@@ -163,7 +163,7 @@ Return node statistics as
 .Bd -literal
 struct ng_car_hookstats {
        uint64_t passed_pkts;   /* Counter for passed packets */
-       uint64_t droped_pkts;   /* Counter for dropped packets */
+       uint64_t dropped_pkts;  /* Counter for dropped packets */
        uint64_t green_pkts;    /* Counter for green packets */
        uint64_t yellow_pkts;   /* Counter for yellow packets */
        uint64_t red_pkts;      /* Counter for red packets */

Modified: head/sys/netgraph/ng_car.c
==============================================================================
--- head/sys/netgraph/ng_car.c  Wed Mar  4 22:31:41 2020        (r358656)
+++ head/sys/netgraph/ng_car.c  Wed Mar  4 22:32:40 2020        (r358657)
@@ -286,7 +286,7 @@ ng_car_rcvdata(hook_p hook, item_p item )
                default:                                \
                        /* Drop packet and return. */   \
                        NG_FREE_ITEM(item);             \
-                       ++hinfo->stats.droped_pkts;     \
+                       ++hinfo->stats.dropped_pkts;    \
                        return (0);                     \
                }                                       \
        } while (0)
@@ -730,7 +730,7 @@ ng_car_enqueue(struct hookinfo *hinfo, item_p item)
            (hinfo->te + len >= NG_CAR_QUEUE_SIZE)) {
                /* Drop packet. */
                ++hinfo->stats.red_pkts;
-               ++hinfo->stats.droped_pkts;
+               ++hinfo->stats.dropped_pkts;
                NG_FREE_M(m);
 
                hinfo->te = 0;

Modified: head/sys/netgraph/ng_car.h
==============================================================================
--- head/sys/netgraph/ng_car.h  Wed Mar  4 22:31:41 2020        (r358656)
+++ head/sys/netgraph/ng_car.h  Wed Mar  4 22:32:40 2020        (r358657)
@@ -42,7 +42,7 @@
 /* Per hook statistics counters */
 struct ng_car_hookstats {
        u_int64_t passed_pkts;  /* Counter for passed packets */
-       u_int64_t droped_pkts;  /* Counter for droped packets */
+       u_int64_t dropped_pkts; /* Counter for dropped packets */
        u_int64_t green_pkts;   /* Counter for green packets */
        u_int64_t yellow_pkts;  /* Counter for yellow packets */
        u_int64_t red_pkts;     /* Counter for red packets */
@@ -50,7 +50,7 @@ struct ng_car_hookstats {
 };
 #define NG_CAR_HOOKSTATS       {                               \
          { "passed",           &ng_parse_uint64_type   },      \
-         { "droped",           &ng_parse_uint64_type   },      \
+         { "dropped",          &ng_parse_uint64_type   },      \
          { "green",            &ng_parse_uint64_type   },      \
          { "yellow",           &ng_parse_uint64_type   },      \
          { "red",              &ng_parse_uint64_type   },      \
_______________________________________________
svn-src-all@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-all
To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"

Reply via email to